
# usage `signal_and_wait signal timeout [pids ...]`
# param: signal - name (or integer value) of the signal to send
# param: timeout - how many seconds (maximum) to wait before return
# param: pids ... - optional list of PIDs
# returns: (exit status) 0 - if all processes terminated (or became zombies); 1 - otherwise (time limit reached)
signal_and_wait()
{
	[ "$#" -gt 2 ] || return 0

	sig="$1"
	timeout="$2"
	shift 2

	# send signal
	kill -s "$sig" "$@" 2>/dev/null

	# build cmdline for test command
	alive=""
	for pid in "$@" ; do
		alive="$alive -o -e /proc/${pid}/cwd"
	done

	# wait $timeout seconds for processes to terminate or to become zombies (zombies do not use files)
	past=0
	# empty string ("") is treated as false
	while [ "" $alive ] ; do
		[ "$past" -lt "$timeout" ] || return 1

		sleep 1
		past=$((past + 1))
	done
	return 0
}

